# TJPCov

TJPCov is a general covariance calculator interface to be used within LSST DESC.

This is currently a placeholder with a handful of functions that may be useful.
See the notebooks in the examples directory.


## Planning

Join the #desc-tjpcov channel on the LSST DESC slack to contribute.

See also [terms of reference](https://github.com/LSSTDESC/TJPCov/blob/master/doc/Terms_of_Reference.md).

